@@ -15,9 +15,10 @@ def create_argparser():
     parser.add_argument("--text", required = True)
     return parser
 
-def initliaze_model():
+def initialize_model():
     global e
-    e = None
+    e=None
+
 def model_topic(path_matrix,path_model,path_vocab,similarity,text):
     global e
     if e == None:
