@@ -12,7 +12,7 @@ class Similarity:
         pass
 
     def cosine_similarity(input_vec, concept_mat):
-        similarity = sk.cosine_similarity(input_vec.transpose().todense(), concept_mat.get_mat().transpose().todense())[0,:]
+        similarity = sk.cosine_similarity(input_vec.transpose().todense(), concept_mat)[0,:]
 
         return similarity
         
